@@ -65,6 +65,9 @@ class StaleElementReferenceException(WebDriverException):
 class InvalidElementStateException(WebDriverException):
     pass
 
+class UnexpectedAlertPresentException(WebDriverException):
+    pass
+
 class NoAlertPresentException(WebDriverException):
     pass
 
@@ -93,11 +96,15 @@ class TimeoutException(WebDriverException):
     """Thrown when a command does not complete in enough time."""
     pass
 
+class MoveTargetOutOfBoundsException(WebDriverException):
+    """Indicates that the target provided to the actions move() method is invalid"""
+    pass
+
 class UnexpectedTagNameException(WebDriverException):
     """Thrown when a support class did not get an expected web element"""
     pass
 
-class InvalidSelectiorException(NoSuchElementException):
+class InvalidSelectorException(NoSuchElementException):
     """ Thrown when the selector which is used to find an element does not return
     a WebElement. Currently this only happens when the selector is an xpath
     expression is used which is either syntactically invalid (i.e. it is not a
