@@ -17,7 +17,7 @@ from selenium.common.exceptions import ElementNotSelectableException
 from selenium.common.exceptions import ElementNotVisibleException
 from selenium.common.exceptions import InvalidCookieDomainException
 from selenium.common.exceptions import InvalidElementStateException
-from selenium.common.exceptions import InvalidSelectiorException
+from selenium.common.exceptions import InvalidSelectorException
 from selenium.common.exceptions import ImeNotAvailableException
 from selenium.common.exceptions import ImeActivationFailedException
 from selenium.common.exceptions import NoSuchElementException
@@ -25,11 +25,12 @@ from selenium.common.exceptions import NoSuchFrameException
 from selenium.common.exceptions import NoSuchWindowException
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.common.exceptions import UnableToSetCookieException
+from selenium.common.exceptions import UnexpectedAlertPresentException
 from selenium.common.exceptions import NoAlertPresentException
 from selenium.common.exceptions import ErrorInResponseException
 from selenium.common.exceptions import TimeoutException
 from selenium.common.exceptions import WebDriverException
-
+from selenium.common.exceptions import MoveTargetOutOfBoundsException
 
 class ErrorCode(object):
     """
@@ -97,7 +98,7 @@ class ErrorHandler(object):
         elif status == ErrorCode.INVALID_SELECTOR \
                 or status == ErrorCode.INVALID_XPATH_SELECTOR \
                 or status == ErrorCode.INVALID_XPATH_SELECTOR_RETURN_TYPER:
-            exception_class = InvalidSelectiorException
+            exception_class = InvalidSelectorException
         elif status == ErrorCode.ELEMENT_IS_NOT_SELECTABLE:
             exception_class = ElementNotSelectableException
         elif status == ErrorCode.INVALID_COOKIE_DOMAIN:
@@ -110,12 +111,16 @@ class ErrorHandler(object):
             exception_class = TimeoutException
         elif status == ErrorCode.UNKNOWN_ERROR:
             exception_class = WebDriverException
+        elif status == ErrorCode.UNEXPECTED_ALERT_OPEN:
+            exception_class = UnexpectedAlertPresentException
         elif status == ErrorCode.NO_ALERT_OPEN:
             exception_class = NoAlertPresentException
         elif status == ErrorCode.IME_NOT_AVAILABLE:
             exception_class = ImeNotAvailableException
         elif status == ErrorCode.IME_ENGINE_ACTIVATION_FAILED:
-            exception_class = ErrorCode.ImeActivationFailedException
+            exception_class = ImeActivationFailedException
+        elif status == ErrorCode.MOVE_TARGET_OUT_OF_BOUNDS:
+            exception_class = MoveTargetOutOfBoundsException
         else:
             exception_class = WebDriverException
         value = response['value']
@@ -138,7 +143,7 @@ class ErrorHandler(object):
                 zeroeth = value['stackTrace'][0]
             except:
                 pass
-            if zeroeth.has_key('methodName'):
+            if 'methodName' in zeroeth:
                 stacktrace = "Method %s threw an error in %s" % \
                     (zeroeth['methodName'],
                     self._value_or_default(zeroeth, 'fileName', '[No file name]'))
@@ -147,4 +152,4 @@ class ErrorHandler(object):
         raise exception_class(message, screen, stacktrace)
 
     def _value_or_default(self, obj, key, default):
-      return obj[key] if obj.has_key(key) else default
+      return obj[key] if key in obj else default
