@@ -16,11 +16,14 @@
 """WebElement implementation."""
 import os
 import zipfile
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:  # 3+
+    from io import StringIO
 import base64
 
 
-from command import Command
+from .command import Command
 from selenium.common.exceptions import WebDriverException 
 from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
@@ -65,7 +68,7 @@ class WebElement(object):
         if resp['value'] is None:
             attributeValue = None
         else:
-            attributeValue = unicode(resp['value'])
+            attributeValue = resp['value']
             if type(resp['value']) is bool:
                 attributeValue = attributeValue.lower()
 
